
#ifndef TRACKVIEW_H
#define TRACKVIEW_H 1
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#include <FL/Fl.H>
#include <FL/Fl_Gl_Window.H>
#include <FL/gl.h>

#include "ScTilemap.h"
//#include "Minimap.h"

#include <list>
using namespace std;
#include "Tuple.h"
#include "PathLine.h"
#include "Startline.h"
#include "ScView.h"
#include <stdlib.h>

struct SearchDirectories {
   char path[1024];
   SearchDirectories *next;
};

enum ToolType {
   kDrawTool, kPathTool, kStartlineTool, kScrollTool
};

// forwards declaration
class TrackEditorUI;

class TrackView : public Fl_Gl_Window {

public:
   
   void newMap(int w, int h);
   void loadMap(const char *fullFilename);
   void importImage(const char *fullFilename);
   void saveMap(const char *fullFilename);
   void installMap(const char *name);
   void uninstallMap(const char *name);
   
   TrackView(int x,int y,int w,int h,const char *l=0);
   ~TrackView();
   
    /*The widget class draw() override.
     *
     *The draw() function initialize Gl for another round o f drawing
     * then calls specialized functions for drawing each of the
     * entities displayed in the cube view.
     *
     */
   void draw();
   void setTool(ToolType t) { tool = t; }
   void setUI(TrackEditorUI *inUI) { ui = inUI; }
   
   void setHorizScrollFrac(double x);
   void setVertScrollFrac(double x);
   
   void resetScroll();
private:
   
   /*  Draw the cube boundaries
   *
   *Draw the faces of the cube using the boxv[] vertices, using
   * GL_LINE_LOOP for the faces. The color is \#defined by TRACKCOLOR.
   */
   void drawTrack();
   void init();
   ScTilemap* loadTileset(const char* tilesetFilename, short border = 0, short seperation = 0, bool blend = false);
   int handle(int event);
   void resize(int x, int y, int w, int h);  // overloaded
   void boundScroll();
   void updateScrollBars();
   
   char dataDir[1024];
   char userDataDir[1024];
   int click_x, click_y;
   int drag_x, drag_y;
   TrackEditorUI *ui;
   ToolType tool;
   ScAnimation animation;
   Startline *startLine;
   ScView *view;
	list<Tuple> pathPolygon;
   SearchDirectories *searchPath;
   ScTilemap *tiles;
//   Minimap *minimap;
};
#endif
